<p align="center">
  <img src="assets/logo.png">
</p>
<h1 align='center'>PySauron</h1>


PySauron is a torch library for anomaly detection offering:
- torchvision-like API for datasets, transforms 
- curated library of anomaly detection datasets



### Running test

```python
pytest --verbose --disable-warnings
```

### TODO
- [x] Datasets: UCF-Crime, Avenue, XD-Violence, ShanghaiTech
- [x] Augmentation: RandomInject, FrameDrop, ChangeDirection
- [x] Test transforms
